baltim
======

Baltimore house sales prices and hedonics, 1978. 
----------------------------------------------------------------

* baltim.dbf: attribute data. (k=17)
* baltim.shp: Point shapefile. (n=211)
* baltim.shx: spatial index.
* baltim.tri.k12.kwt: kernel weights using a triangular kernel with 12 nearest neighbors in KWT format.
* baltim_k4.gwt: nearest neighbor weights (4nn) in GWT format.
* baltim_q.gal: queen contiguity weights in GAL format.
* baltimore.geojson: spatial weights in geojson format.

Source: Dubin, Robin A. (1992). Spatial autocorrelation and neighborhood quality. Regional Science and Urban Economics 22(3), 433-452.